@@ -1,9 +1,9 @@
 require 'ai.core.core'
 require 'ai.core.idle.civilian'
 require 'ai.core.misc.distress'
-local fmt = require "format"
 
 mem.lanes_useneutral = true
+mem.atk_skill = 0
 
 local bribe_no_list = {
    _([["Just leave me alone!"]]),
@@ -12,6 +12,7 @@ local bribe_no_list = {
 }
 
 function create ()
+   create_pre()
    -- Credits.
    ai.setcredits( rnd.rnd(ai.pilot():ship():price()/500, ai.pilot():ship():price()/200) )
 
@@ -26,10 +27,9 @@ function hail ()
    -- No bribe
    mem.bribe_no = bribe_no_list[ rnd.rnd(1,#bribe_no_list) ]
 
-   -- Refueling
+   -- Refuelling
    mem.refuel = rnd.rnd( 1000, 3000 )
-   mem.refuel_msg = fmt.f(_([["I'll supply your ship with fuel for {credits}."]]),
-         {credits=fmt.credits(mem.refuel)})
+   mem.refuel_msg = _([["I'll supply your ship with fuel for {credits}."]])
 
    mem.setuphail = true
 end
