@@ -1,7 +1,6 @@
 require 'ai.core.core'
 require 'ai.core.idle.civilian'
 require 'ai.core.misc.distress'
-local fmt = require "format"
 
 mem.careful   = false
 mem.lanes_useneutral = true
@@ -19,6 +18,8 @@ function create ()
    local price = ai.pilot():ship():price()
    ai.setcredits( rnd.rnd(price/150, price/50) ) -- Target for crime
 
+   mem.atk_skill = 0.3 + 0.3*rnd.sigma()
+
    create_post()
 end
 
@@ -39,8 +40,7 @@ function hail ()
    mem.bribe_no      = nil
 
    mem.refuel = mem.refuel_base
-   mem.refuel_msg = fmt.f(_([["I'll supply your ship with fuel for {credits}."]]),
-         {credits=fmt.credits(mem.refuel)})
+   mem.refuel_msg = _([["I'll supply your ship with fuel for {credits}."]])
 
    -- No bribe
    mem.bribe_no = bribe_msg_list[ rnd.rnd(1,#bribe_msg_list) ]
