@@ -75,7 +75,7 @@ function begin ()
 
    hook.timer(3.0, "merchant")
    hook.timer(7.0, "attack")
-   hook.timer(12.0, "defense")
+   hook.timer(12.0, "defence")
    battleEnded = false
 
    hook.rm(jumphook)
@@ -254,7 +254,7 @@ function attack ()
    goda:land(source_planet)
 end
 
-function defense ()
+function defence ()
    defAttHook = {}
    local n = rnd.rnd(3,6)
    local name = _("Local Warlord's Force")
@@ -268,8 +268,8 @@ function defense ()
    defenders[2*n+1] = pilot.add( "Dvaered Phalanx", "Dvaered", source_planet, name )
    defenders[2*n+2] = pilot.add( "Dvaered Phalanx", "Dvaered", source_planet, name )
    defenders[2*n+3] = pilot.add( "Dvaered Vigilance", "Dvaered", source_planet, name )
-   local godd       = pilot.add( "Dvaered Goddard", "Dvaered", source_planet, name )
-   defenders[2*n+4] = godd
+   local goddard    = pilot.add( "Dvaered Goddard", "Dvaered", source_planet, name )
+   defenders[2*n+4] = goddard
 
    defenders = arrangeList(defenders)  --The heaviest ships will surround the leader
    local form = formation.random_key()
@@ -280,8 +280,8 @@ function defense ()
       m.formation = form
       m.aggressive = false
 
-      if j ~= godd then
-         j:setLeader(godd)
+      if j ~= goddard then
+         j:setLeader(goddard)
       end
 
       defAttHook[i] = hook.pilot(j, "attacked", "defenderAttacked")
@@ -404,5 +404,5 @@ function defenderDeath(victim, arg)
 end
 
 function leave ()
-    evt.finish()
+   evt.finish()
 end
