@@ -1,11 +1,9 @@
 --[[
 <?xml version='1.0' encoding='utf8'?>
 <event name="Travel Log">
-  <trigger>enter</trigger>
+  <location>enter</location>
   <chance>100</chance>
-  <flags>
-   <unique />
-  </flags>
+  <unique />
  </event>
  --]]
 --[[
@@ -20,7 +18,6 @@
 local fmt = require "format"
 
 local attacked, lastsys -- Non-persistent state
--- luacheck: globals jumpin land player_attacked (Hook functions passed by name)
 
 function create ()
    shiplog.create( "travel", _("Travel Log"), _("Travel"), false, 20 )
@@ -51,7 +48,7 @@ end
 
 
 function land ()
-   local p = planet.cur()
+   local p = spob.cur()
    local s = p:system()
    shiplog.append( "travel", fmt.f(_("Landed on {pnt} in the {sys} system"), {pnt=p, sys=s} ) )
    evt.finish( false )
