@@ -263,8 +263,7 @@ function spawnDV()
    obstinate:setVisplayer()
    obstinate:outfitRm("all")
    obstinate:outfitAdd("Engine Reroute")
-   obstinate:outfitAdd("Small Shield Booster")
-   obstinate:outfitAdd("Small Shield Booster")
+   obstinate:outfitAdd("Small Shield Booster",2)
    ai_setup.setup(obstinate)
    hook.pilot(obstinate, "attacked", "attackedObstinate")
    hook.pilot(obstinate, "death", "deathObstinate")
@@ -297,10 +296,10 @@ end
 
 -- Helper function
 local function setFLF( j )
-  hook.pilot(j, "death", "deathFLF")
-  j:setNoDisable(true)
-  j:setHostile()
-  j:setVisible(true)
+   hook.pilot(j, "death", "deathFLF")
+   j:setNoDisable(true)
+   j:setHostile()
+   j:setVisible(true)
 end
 
 
@@ -445,7 +444,7 @@ end
 
 function destroyBase()
    if base:exists() then
-     base:setHealth( -1, 0 )
+      base:setHealth( -1, 0 )
    end
 end
 
@@ -464,7 +463,7 @@ local function controlFleet( fleetCur, pos, off )
    for i, j in ipairs( fleetCur ) do
       if j:exists() then
          local basedist = vec2.dist(j:pos(), base:pos())
-	   local nearest
+         local nearest
 
          -- Get closest hostile
          local distance = 2500
