@@ -28,8 +28,7 @@
       minor edits by Infiltrator
       - Mission fixed to suit big systems (Anatolis, 11/02/2011)
 
-   Rescue a VIP stranded on a disabled ship in a system while FLF and Dvaered
-    are fighting.
+   Rescue a VIP stranded on a disabled ship in a system while FLF and Dvaered are fighting.
 
    Stages:
 
@@ -84,9 +83,9 @@ function accept ()
 
    -- Flavour text and mini-briefing
    vn.label("accept")
-   soldner(fmt.f(_([[Commander Soldner nods and continues, "We've had reports that a transport vessel came under attack while carrying a VIP. They managed to escape, but the engine ended up giving out in the {sys} system. The ship is now disabled, and we need someone to board the ship and rescue the VIP. There have been many FLF ships detected near the sector, but we've managed to organise a Dvaered escort for you.]]),
+   soldner(fmt.f(_([[Commander Soldner nods and continues, "We've had reports that a transport vessel came under attack while carrying a VIP. They managed to escape, but the engine ended up giving out in the {sys} system. The ship is now disabled, and we need someone to board the ship and rescue the VIP. There have been many FLF ships detected near the sector, but we've managed to organize a Dvaered escort for you.]]),
       {sys=destsys}))
-   soldner(fmt.f(_([["You're going to have to fly to the {sys} system, find and board the transport ship to rescue the VIP, and then fly back. The sector is most likely going to be hot. That's where your Dvaered escorts will come in. Their mission will be to distract and neutralise all possible hostiles. You must not allow the transport ship to be destroyed before you rescue the VIP. His survival is vital."]]),
+   soldner(fmt.f(_([["You're going to have to fly to the {sys} system, find and board the transport ship to rescue the VIP, and then fly back. The sector is most likely going to be hot. That's where your Dvaered escorts will come in. Their mission will be to distract and neutralize all possible hostiles. You must not allow the transport ship to be destroyed before you rescue the VIP. His survival is vital."]]),
       {sys=destsys}))
    soldner(fmt.f( _([["Be careful with the Dvaered; they can be a bit blunt, and might accidentally destroy the transport ship. If all goes well, you'll be paid {credits} when you return with the VIP. Good luck, pilot."]]),
       {credits=fmt.credits(emp.rewards.es02)} ) )
@@ -125,7 +124,7 @@ function land ()
    if mem.landed == mem.ret then
       -- Successfully rescued the VIP
       if mem.misn_stage == 2 then
-         local getlicense = not diff.isApplied( "heavy_combat_vessel_license" )
+         local getlicence = not diff.isApplied( "heavy_combat_vessel_licence" )
 
          vn.clear()
          vn.scene()
@@ -133,14 +132,14 @@ function land ()
          vn.transition( emp.soldner.transition )
 
          vn.na(_([[You land at the starport. It looks like the VIP has already recovered. He thanks you profusely before heading off. You proceed to pay Commander Soldner a visit. He seems to be happy, for once.]]))
-         if getlicense then
-            soldner(_([["It seems like you managed to pull it off. I had my doubts at first, but you've proven to be a very skilled pilot. Oh, and I've cleared you for a Heavy Combat Vessel License; congratulations! We have nothing more for you now, but check in periodically in case something comes up for you."]]))
+         if getlicence then
+            soldner(_([["It seems like you managed to pull it off. I had my doubts at first, but you've proven to be a very skilled pilot. Oh, and I've cleared you for a Heavy Combat Vessel Licence; congratulations! We have nothing more for you now, but check in periodically in case something comes up for you."]]))
             vn.sfxBingo()
-            vn.na(_([[You can now purchase the #bHeavy Combat Vessel License#0.]]))
+            vn.na(_([[You can now purchase the #bHeavy Combat Vessel Licence#0.]]))
 
             vn.func( function ()
-               emp.addShippingLog( _([[You successfully rescued a VIP for the Empire and have been cleared for a Heavy Combat Vessel License; you can now buy one at the outfitter.]]) )
-               diff.apply("heavy_combat_vessel_license")
+               emp.addShippingLog( _([[You successfully rescued a VIP for the Empire and have been cleared for a Heavy Combat Vessel Licence; you can now buy one at the outfitter.]]) )
+               diff.apply("heavy_combat_vessel_licence")
             end )
          else
             soldner(_([["It seems like you managed to pull it off. I had my doubts at first, but you've proven to be a very skilled pilot. We have nothing more for you now, but check in periodically in case something comes up for you."]]) )
