@@ -617,7 +617,7 @@ Eventually when all argumentation is exhausted the different representatives rep
    }
 
    vn.label("06_kex")
-   vn.na(_([["You try to make your way to where Kex fell, but don't find them. As the smoke keeps on filling the room, you have no choice but to head towards to the door and try to save yourself. You jump over bodies and try to push yourself out of the room."]]))
+   vn.na(_([[You try to make your way to where Kex fell, but don't find them. As the smoke keeps on filling the room, you have no choice but to head towards to the door and try to save yourself. You jump over bodies and try to push yourself out of the room.]]))
    vn.jump("06")
 
    vn.label("06_getout")
@@ -661,6 +661,9 @@ She tries to adjust her position a bit to breath more easily, the pain is clear
       end
       minerva.log.pirate(fmt.f(_([[You went with Zuri to participate in a trial to decide the future of Minerva Station. Maikki took the role of the Minerva Station defendant when the CEO passed out. You were called as a witness and your integrity was question.{winnerstr} Suddenly, Kex interrupted claimed that Minerva Station was a secret weapon laboratory, before trying to activate a weapon. This caused panic and a firefight to break out. You managed to escape with your life and found a seriously injured Zuri with an unconscious Kex who now need help getting off of {spb}.]]),
          {winnerstr=winnerstr, spb=trialspb}))
+      -- Have to manually start the mission so that the NPC shows up right away
+      -- This skips all the checks the beginning including mission prerequisites so it works
+      naev.missionStart("Minerva Finale 1")
       misn.finish(true)
    end
 end
