@@ -71,8 +71,8 @@ function create ()
 
    -- Note: this mission makes no system claims
 
-   mem.credits_factor = 500 + 300 * dist
-   mem.credits_mod = 10e3 * rnd.sigma()
+   mem.credits_factor = 300 + 200 * dist
+   mem.credits_mod = 10e3 * (1 + rnd.sigma())
 
    for i,p in ipairs( dest_planets ) do
       misn.markerAdd( p, "computer" )
@@ -85,17 +85,22 @@ function create ()
 end
 
 function accept ()
+   local q = player.fleetCargoMissionFree()
+   if q <= 0 then
+      vntk.msg(_("Not Enough Cargo Space"), _([[You need to actually have cargo space available to be able to accept waste containers.]]))
+   end
+
    misn.accept()
 
-   local q = player.fleetCargoMissionFree()
    mem.credits = mem.credits_factor * q + mem.credits_mod
 
    lmisn.sfxMoney()
    local txt = text[ rnd.rnd( 1, #text ) ]
-   vntk.msg(_("Waste Containers Loaded"), fmt.f( txt, {credits = fmt.credits( mem.credits ) } ) )
+   vntk.msg(_("Waste Containers Loaded"), fmt.f( txt, {credits = "#g"..fmt.credits( mem.credits ).."#0" } ) )
 
    local c = commodity.new( N_("Waste Containers"), N_("A bunch of waste containers leaking all sorts of indescribable liquids. You hope they don't leak onto your ship.") )
    mem.cid = misn.cargoAdd( c, q )
+   mem.quantity = q
    player.pay( mem.credits )
 
    misn.osdCreate( _("Waste Dump"), {_("Land on any garbage collection facility (indicated on your map) to drop off the Waste Containers")} )
@@ -117,24 +122,47 @@ end
 
 function abort ()
    if player.isLanded() then
-      local fine = math.min( player.credits(), 2 * mem.credits )
+      local fine
       local msg
       local spb = spob.cur()
-      if spb:services().inhabited then
-         msg = fmt.f(_("In your desperation to rid yourself of the garbage, you clumsily eject it from your cargo pod while you are still landed. Garbage spills all over the hangar and local officials immediately take notice. After you apologize profusely and explain the situation was an accident, the officials let you off with a fine of {credits}."), {credits=fmt.credits(fine)} )
+      if system.cur().tags().wildspace then
+         fine = nil
+         msg = fmt.f(_("You eject your waste pods while landed at {spob} without any interference. Environmentalism be damned!"),
+            {spob=spb})
+      elseif spb:services().inhabited then
+         fine = math.min( player.credits(), 1.5 * mem.credits )
+         msg = fmt.f(_("In your desperation to rid yourself of the garbage, you clumsily eject it from your cargo pod while you are still landed. Garbage spills all over the hangar and local officials immediately take notice. After you apologize profusely and explain the situation was an accident, the officials let you off with a fine of {credits}."),
+            {credits="#r"..fmt.credits(fine).."#0"} )
       else
-         msg = fmt.f(_("Thinking {spob} to be devoid of people, you eject your cargo pod while landed. To your surprise, you find a wandering environmentalist knocking on your ship airlock. You make the mistake of opening the airlock and letting them in. After having to hear a tirade about how you are polluting pristine locations around the galaxy, you end up paying them {credits} to leave and clean up the mess you made."), {credits=fmt.credits(fine), spob=spb} )
+         -- it's better than dumping in an inhabited place anyway
+         fine = math.min( player.credits(), 0.75 * mem.credits )
+         msg = fmt.f(_("Thinking {spob} to be devoid of people, you eject your cargo pod while landed. To your surprise, you find a wandering environmentalist knocking on your ship airlock. You make the mistake of opening the airlock and letting them in. After having to hear a tirade about how you are polluting pristine locations around the galaxy, you end up paying them {credits} to leave and clean up the mess you made."),
+            {credits="#r"..fmt.credits(fine).."#0", spob=spb} )
       end
       vntk.msg(_("Dirty Deed"), msg)
-      player.pay( -fine )
-      misn.finish( false )
+      if fine then
+         player.pay( -fine )
+      end
 
+      -- Hit all the presences in the system
+      for fct,val in pairs( system.cur():presences() ) do
+         local fcthit = math.max( (mem.quantity or 0)^0.503-14, 1 )
+         faction.hit( fct, -fcthit, system.cur(), nil, true )
+      end
+
+      misn.finish( false )
    else
       local txt = abort_text[ rnd.rnd( 1, #abort_text ) ]
       vntk.msg(_("Dirty Deed"), txt)
 
       misn.cargoJet( mem.cid )
 
+      -- Hit all the presences in the system
+      for fct,val in pairs( system.cur():presences() ) do
+         local fcthit = math.max( (mem.quantity or 0)^0.503-9, 3 )
+         faction.hit( fct, -fcthit, system.cur(), nil, true )
+      end
+
       -- Make everyone angry
       for i,p in ipairs(pilot.get()) do
          if not p:withPlayer() then
@@ -194,7 +222,9 @@ function abort ()
       end
 
       -- No landing, filthy waste dumper!
-      player.landAllow( false, _("Get lost, waste dumping scum! We don't want you here!") )
+      for i,spb in ipairs(system.cur():spobs()) do
+         spb:setHostile(true)
+      end
 
       misn.finish( true )
    end
