@@ -1,27 +1,23 @@
 --[[
 <?xml version='1.0' encoding='utf8'?>
 <mission name="Pirate Patrol">
- <avail>
-  <priority>4</priority>
-  <chance>560</chance>
-  <location>Computer</location>
-  <faction>Wild Ones</faction>
-  <faction>Black Lotus</faction>
-  <faction>Raven Clan</faction>
-  <faction>Dreamer Clan</faction>
-  <faction>Pirate</faction>
- </avail>
+ <priority>4</priority>
+ <chance>560</chance>
+ <location>Computer</location>
+ <faction>Wild Ones</faction>
+ <faction>Black Lotus</faction>
+ <faction>Raven Clan</faction>
+ <faction>Dreamer Clan</faction>
+ <faction>Pirate</faction>
  <notes>
   <tier>3</tier>
  </notes>
 </mission>
 --]]
 --[[
-
    Pirate Patrol
 
    Pirate version of the patrol mission.
-
 --]]
 local pir = require "common.pirate"
 require "missions.neutral.patrol"
@@ -40,10 +36,6 @@ abandon_text = {
 }
 
 
--- Mission details
-mem.misn_title  = _("#rPIRACY:#0 Patrol of the {sys} System ({fct})")
-mem.misn_desc   = _("A local crime boss has offered a job to patrol the {sys} system in an effort to keep outsiders from discovering this Pirate stronghold. You will be tasked with checking various points and eliminating any outsiders along the way.")
-
 -- Messages
 msg = {
    _("Point secure."),
@@ -66,9 +58,14 @@ mem.use_hidden_jumps = true
 local create_original = create
 function create ()
    mem.paying_faction = pir.systemClanP()
+   mem.misn_title  = pir.prefix(mem.paying_faction).._("Patrol of the {sys} System")
+   mem.misn_desc   = _([[A local crime boss has offered a job to patrol the {sys} system in an effort to keep outsiders from discovering this Pirate stronghold. You will be tasked with checking various points and eliminating any outsiders along the way.
+
+#nPatrol System:#0 {sys}
+#nPatrol Points:#0 {amount}]])
    if pir.factionIsClan( mem.paying_faction ) then
       -- mem.misn_desc gets fmt.f'd in the main script
-      mem.misn_desc = mem.misn_desc..pir.reputationMessage( mem.paying_faction )
+      mem.misn_desc = mem.misn_desc.."\n"..pir.reputationMessage( mem.paying_faction )
    end
 
    create_original()
