@@ -43,15 +43,15 @@ function create()
    --set the mission stuff
    misn.setTitle(_("The Patrol"))
    misn.setReward(mem.reward)
-   misn.setNPC(_("An Imposing Man"), "sirius/unique/draga.webp", _("This man leans against the bar while looking right at you."))
+   misn.setNPC(_("An Imposing Man"), "sirius/unique/draga", _("This man leans against the bar while looking right at you."))
 end
 
 function accept()
    if tk.yesno( _("The Patrol"), fmt.f(_([[You walk up to the intimidating man. He's dressed smartly in cool, dark black business attire, with a large smile spread across his face.
-    "Ahh, so you're {player}! Everyone has been talking about you," he says. "Allow me to introduce myself. My name is Draga, high commander of Nasin's operations. You remember us, right? People in our organization have started to take notice of your actions. Maybe it is the will of Sirichana that you come to us! If that is the case, then I have an offer you can't refuse. A chance to really prove yourself as more than a glorified courier. You see... we are expecting a Sirian patrol any hectosecond now, and we want you to... take care of it. What do you say? We could really use your help."]]), {player=player.name()} ) ) then
+   "Ahh, so you're {player}! Everyone has been talking about you," he says. "Allow me to introduce myself. My name is Draga, high commander of Nasin's operations. You remember us, right? People in our organization have started to take notice of your actions. Maybe it is the will of Sirichana that you come to us! If that is the case, then I have an offer you can't refuse. A chance to really prove yourself as more than a glorified courier. You see... we are expecting a Sirian patrol any hectosecond now, and we want you to... take care of it. What do you say? We could really use your help."]]), {player=player.name()} ) ) then
       misn.accept()
       tk.msg( _("The Patrol"), _([["Marvelous! I knew I could count on you! Don't you worry; you'll be fighting alongside some of our finest pilots. I know you can drive those Sirii off!
-    "Oh, and one last thing: don't even think of bailing out on us at the last second. If you jump out or land before your mission is completed, consider yourself fired."]]) )
+   "Oh, and one last thing: don't even think of bailing out on us at the last second. If you jump out or land before your mission is completed, consider yourself fired."]]) )
 
       misn.setDesc(fmt.f(_("You have been hired once again by Nasin, this time to destroy a Sirius patrol that has entered {sys}."), {sys=mem.homesys}))
       misn.markerAdd(mem.homeasset, "high")
@@ -73,8 +73,8 @@ function takeoff()
    pilot.toggleSpawn("Sirius",false) --the only Sirius i want in the system currently is the recon force
    recon = fleet.add( 1, {"Sirius Preacher", "Sirius Fidelity", "Sirius Fidelity", "Sirius Fidelity"}, "Sirius", system.get("Herakin") )
    attackers = fleet.add( 1, {"Admonisher", "Lancelot", "Lancelot", "Lancelot"},
-                            "Nasin", mem.homeasset,
-                            {_("Nasin Admonisher"), _("Nasin Lancelot"), _("Nasin Lancelot"), _("Nasin Lancelot")} ) --a little assistance
+      "Nasin", mem.homeasset,
+      {_("Nasin Admonisher"), _("Nasin Lancelot"), _("Nasin Lancelot"), _("Nasin Lancelot")} ) --a little assistance
    mem.n_recon = #recon --using a deathcounter to track success
    for i,p in ipairs(recon) do
       p:setHilight(true)
@@ -104,7 +104,7 @@ end
 
 function land()
    if mem.finished ~= 1 then
-      tk.msg(_("The Patrol"),_([[Draga's face goes red with fury when he sees you. For a moment you start to worry he might beat you into a pulp for abandoning your mission, but he moves along, fuming. You breathe a sigh of relief; you may have angered Nasin, but at least you're still alive.]])) --landing pre-emptively is a bad thing.
+      tk.msg(_("The Patrol"),_([[Draga's face goes red with fury when he sees you. For a moment you start to worry he might beat you into a pulp for abandoning your mission, but he moves along, fuming. You breathe a sigh of relief; you may have angered Nasin, but at least you're still alive.]])) --landing preemptively is a bad thing.
       faction.hit("Nasin",-20)
       misn.finish(false)
    elseif spob.cur() == mem.homeasset and mem.finished == 1 then
@@ -118,7 +118,7 @@ function land()
    end
 end
 
-function out_sys_failure() --jumping pre-emptively is a bad thing.
+function out_sys_failure() --jumping preemptively is a bad thing.
    if system.cur() ~= mem.homesys then
       tk.msg(_("The Patrol"), _([[As you abandon your mission, you receive a message from Draga saying that Nasin has no need for deserters. You hope you made the right decision.]]))
       faction.hit("Nasin",-20)
