@@ -8,9 +8,9 @@ local audio = require "love.audio"
 local ferals = {}
 
 ferals.sfx = {
-   spacewhale1 = audio.newSource( "snd/sounds/spacewhale1.ogg" ),
-   spacewhale2 = audio.newSource( "snd/sounds/spacewhale2.ogg" ),
-   bite = audio.newSource( "snd/sounds/crash1.ogg" ),
+   spacewhale1 = audio.newSource( "snd/sounds/spacewhale1" ),
+   spacewhale2 = audio.newSource( "snd/sounds/spacewhale2" ),
+   bite = audio.newSource( "snd/sounds/crash1" ),
 }
 
 function ferals.faction ()
